@@ -90,7 +90,7 @@ class MiApi:
 
 
 @lru_cache(100)
-def mi_meta(endpoint: str, program: Optional[str] = None, transaction: Optional[str] = None) -> Union[MiPrograms, MiProgramMetadata, MiTransactionMetadata, MiError]:
+def mi_meta(endpoint: str, program: Optional[str] = None, transaction: Optional[str] = None) -> Union[MiPrograms, MiProgramMetadata, MiTransactionMetadata]:
     ''' Fetch metatdata from the API. Wrapper function for the following functions:
     - mi_meta_list
     - mi_meta_program
@@ -147,7 +147,7 @@ def mi_meta(endpoint: str, program: Optional[str] = None, transaction: Optional[
         raise RuntimeError('No case defined for program={program} and transaction={transaction}')
 
 
-def mi_api_execute(endpoint: str, program: str, transaction: str, **kwargs) -> Union[MiRecords, MiError]:
+def mi_api_execute(endpoint: str, program: str, transaction: str, **kwargs) -> MiRecords:
     ''' Executes API calls, either read or write depending on the transaction.
     The **kwargs represents the input values. The key word "maxrecs" is treated as a special case
     and represents the maximum number of return records. Default is 100, 0 will be all. the key word
